==> haskell-uri-encode-1.5.0.6-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uri-encode
version:              1.5.0.6
visibility:           public
id:                   uri-encode-1.5.0.6-H5HXPyBExCLAWcoTNwt0LD
key:                  uri-encode-1.5.0.6-H5HXPyBExCLAWcoTNwt0LD
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding.
description:          Unicode aware uri-encoding.
category:             Network, Web
abi:                  604a527cac8f734a8c247a50a5cf8161
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-8.10.2/site-local/uri-encode-1.5.0.6
library-dirs:         /usr/lib/ghc-8.10.2/site-local/uri-encode-1.5.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/uri-encode-1.5.0.6
hs-libraries:         HSuri-encode-1.5.0.6-H5HXPyBExCLAWcoTNwt0LD
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    network-uri-2.6.3.0-61P6BJ4psX64KMmEkAEQRu text-1.2.3.2
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-encode-1.5.0.6-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uri-encode
version:              1.5.0.6
visibility:           public
id:                   uri-encode-1.5.0.6-BZrXAbAifhM9BpLb6UPY4u
key:                  uri-encode-1.5.0.6-BZrXAbAifhM9BpLb6UPY4u
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding.
description:          Unicode aware uri-encoding.
category:             Network, Web
abi:                  681d71e2f6168054dcb2f123c3c22f31
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-8.10.2/site-local/uri-encode-1.5.0.6
library-dirs:         /usr/lib/ghc-8.10.2/site-local/uri-encode-1.5.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/uri-encode-1.5.0.6
hs-libraries:         HSuri-encode-1.5.0.6-BZrXAbAifhM9BpLb6UPY4u
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    network-uri-2.6.3.0-6huqpvjP5AA7URohCDVsI5 text-1.2.3.2
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
